@@ -429,32 +429,34 @@ static int exec_helper(struct libmnt_context *cxt)
 		type = mnt_fs_get_fstype(cxt->fs);
 
 		args[i++] = cxt->helper;		/* 1 */
-		args[i++] = mnt_fs_get_srcpath(cxt->fs);/* 2 */
-		args[i++] = mnt_fs_get_target(cxt->fs);	/* 3 */
 
 		if (mnt_context_is_sloppy(cxt))
-			args[i++] = "-s";		/* 4 */
+			args[i++] = "-s";		/* 2 */
 		if (mnt_context_is_fake(cxt))
-			args[i++] = "-f";		/* 5 */
+			args[i++] = "-f";		/* 3 */
 		if (mnt_context_is_nomtab(cxt))
-			args[i++] = "-n";		/* 6 */
+			args[i++] = "-n";		/* 4 */
 		if (mnt_context_is_verbose(cxt))
-			args[i++] = "-v";		/* 7 */
+			args[i++] = "-v";		/* 5 */
 		if (o) {
-			args[i++] = "-o";		/* 8 */
-			args[i++] = o;			/* 9 */
+			args[i++] = "-o";		/* 6 */
+			args[i++] = o;			/* 7 */
 		}
 		if (type
 		    && strchr(type, '.')
 		    && !endswith(cxt->helper, type)) {
-			args[i++] = "-t";		/* 10 */
-			args[i++] = type;		/* 11 */
+			args[i++] = "-t";		/* 8 */
+			args[i++] = type;		/* 9 */
 		}
 		if (namespace) {
-			args[i++] = "-N";		/* 11 */
-			args[i++] = namespace;		/* 12 */
+			args[i++] = "-N";		/* 10 */
+			args[i++] = namespace;		/* 11 */
 		}
-		args[i] = NULL;				/* 13 */
+
+		args[i++] = mnt_fs_get_srcpath(cxt->fs);/* 12 */
+		args[i++] = mnt_fs_get_target(cxt->fs);	/* 13 */
+
+		args[i] = NULL;				/* 14 */
 		for (i = 0; args[i]; i++)
 			DBG(CXT, ul_debugobj(cxt, "argv[%d] = \"%s\"",
 							i, args[i]));
@@ -575,6 +577,15 @@ static int is_success_status(struct libmnt_context *cxt)
 	return 0;
 }
 
+static int is_termination_status(struct libmnt_context *cxt)
+{
+	if (is_success_status(cxt))
+		return 1;
+
+	return mnt_context_get_syscall_errno(cxt) != EINVAL &&
+	       mnt_context_get_syscall_errno(cxt) != ENODEV;
+}
+
 /* try mount(2) for all items in comma separated list of the filesystem @types */
 static int do_mount_by_types(struct libmnt_context *cxt, const char *types)
 {
@@ -615,7 +626,7 @@ static int do_mount_by_types(struct libmnt_context *cxt, const char *types)
 			rc = do_mount(cxt, p);
 		p = end ? end + 1 : NULL;
 		free(autotype);
-	} while (!is_success_status(cxt) && p);
+	} while (!is_termination_status(cxt) && p);
 
 	free(p0);
 	return rc;
@@ -660,10 +671,7 @@ static int do_mount_by_pattern(struct libmnt_context *cxt, const char *pattern)
 	for (fp = filesystems; *fp; fp++) {
 		DBG(CXT, ul_debugobj(cxt, " ##### trying '%s'", *fp));
 		rc = do_mount(cxt, *fp);
-		if (is_success_status(cxt))
-			break;
-		if (mnt_context_get_syscall_errno(cxt) != EINVAL &&
-		    mnt_context_get_syscall_errno(cxt) != ENODEV)
+		if (is_termination_status(cxt))
 			break;
 	}
 	mnt_free_filesystems(filesystems);
