@@ -253,9 +253,9 @@ static void __attribute__((__noreturn__)) usage(void)
 		" -p, --dispatch <mode>         set dispatching mode\n"
 		" -r, --rescan                  trigger rescan of cpus\n"
 		), stdout);
-	printf(USAGE_HELP_OPTIONS(31));
+	fprintf(stdout, USAGE_HELP_OPTIONS(31));
 
-	printf(USAGE_MAN_TAIL("chcpu(8)"));
+	fprintf(stdout, USAGE_MAN_TAIL("chcpu(8)"));
 	exit(EXIT_SUCCESS);
 }
 
